# kt17py

A Python wrapper to the FORTRAN code for the KT17 dynamic magnetic field model for Mercury's magnetosphere.

See Korth, H., Johnson, C. L., Philpott, L.,Tsyganenko, N. A., & Anderson, B. J.(2017). A dynamic model of Mercury’s
magnetospheric magnetic field. Geophysical Research Letters, 44. https://doi.org/10.1002/2017GL074699